"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lineHeights = exports.fontWeights = exports.fonts = exports.remTextSansSizes = exports.remBodySizes = exports.remHeadlineSizes = exports.remTitlepieceSizes = exports.textSansSizes = exports.bodySizes = exports.headlineSizes = exports.titlepieceSizes = exports.textSans = exports.body = exports.headline = exports.titlepiece = void 0;
const api_1 = require("./api");
const data_1 = require("./data");
Object.defineProperty(exports, "bodySizes", { enumerable: true, get: function () { return data_1.bodySizes; } });
Object.defineProperty(exports, "fonts", { enumerable: true, get: function () { return data_1.fontMapping; } });
Object.defineProperty(exports, "fontWeights", { enumerable: true, get: function () { return data_1.fontWeightMapping; } });
Object.defineProperty(exports, "headlineSizes", { enumerable: true, get: function () { return data_1.headlineSizes; } });
Object.defineProperty(exports, "lineHeights", { enumerable: true, get: function () { return data_1.lineHeightMapping; } });
Object.defineProperty(exports, "remBodySizes", { enumerable: true, get: function () { return data_1.remBodySizes; } });
Object.defineProperty(exports, "remHeadlineSizes", { enumerable: true, get: function () { return data_1.remHeadlineSizes; } });
Object.defineProperty(exports, "remTextSansSizes", { enumerable: true, get: function () { return data_1.remTextSansSizes; } });
Object.defineProperty(exports, "remTitlepieceSizes", { enumerable: true, get: function () { return data_1.remTitlepieceSizes; } });
Object.defineProperty(exports, "textSansSizes", { enumerable: true, get: function () { return data_1.textSansSizes; } });
Object.defineProperty(exports, "titlepieceSizes", { enumerable: true, get: function () { return data_1.titlepieceSizes; } });
const object_styles_to_string_1 = require("./object-styles-to-string");
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-typography--page#titlepiece) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/358767)
 *
 * ```
 * font-family: 'GT Guardian Titlepiece';
 * ```
 *
 * `titlepiece.small()` -> 42px
 *
 * `titlepiece.medium()` -> 50px
 *
 * `titlepiece.large()` -> 70px
 */
const titlepiece = Object.fromEntries(Object.entries(api_1.titlepiece).map(([key, func]) => {
    return [
        key,
        (options) => (0, object_styles_to_string_1.objectStylesToString)(func(options)),
    ];
}));
exports.titlepiece = titlepiece;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-typography--page#headline) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/7310bd)
 *
 * ```
 * font-family: 'GH Guardian Headline';
 * ```
 *
 * `headline.xxxsmall()` -> 17px
 *
 * `headline.xxsmall()` -> 20px
 *
 * `headline.xsmall()` -> 24px
 *
 * `headline.small()` -> 28px
 *
 * `headline.medium()` -> 34px
 *
 * `headline.large()` -> 42px
 *
 * `headline.xlarge()` -> 50px
 */
const headline = Object.fromEntries(Object.entries(api_1.headline).map(([key, func]) => {
    return [
        key,
        (options) => (0, object_styles_to_string_1.objectStylesToString)(func(options)),
    ];
}));
exports.headline = headline;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-typography--page#body) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/88cd8e)
 *
 * ```
 * font-family: 'GuardianTextEgyptian';
 * ```
 *
 * `body.small()` -> 15px
 *
 * `body.medium()` -> 17px
 */
const body = Object.fromEntries(Object.entries(api_1.body).map(([key, func]) => {
    return [
        key,
        (options) => (0, object_styles_to_string_1.objectStylesToString)(func(options)),
    ];
}));
exports.body = body;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-typography--page#text-sans) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/076605)
 *
 * ```
 * font-family: 'GuardianTextSans';
 * ```
 *
 * `textSans.xxsmall()` -> 12px
 *
 * `textSans.xsmall()` -> 14px
 *
 * `textSans.small()` -> 15px
 *
 * `textSans.medium()` -> 17px
 *
 * `textSans.large()` -> 20px
 *
 * `textSans.xlarge()` -> 24px
 *
 * `textSans.xxlarge()` -> 28px
 *
 * `textSans.xxxlarge()` -> 34px
 */
const textSans = Object.fromEntries(Object.entries(api_1.textSans).map(([key, func]) => {
    return [
        key,
        (options) => (0, object_styles_to_string_1.objectStylesToString)(func(options)),
    ];
}));
exports.textSans = textSans;
//# sourceMappingURL=index.js.map